@@ -5,7 +5,7 @@
 # Joan Ntzougani, gravitalsun@hotmail.com
 
 package Dancer2::Plugin::WebService;
-our	$VERSION = '4.3.2';
+our	$VERSION = '4.3.3';
 use	strict;
 use	warnings;
 use Encode;
@@ -179,7 +179,7 @@ opendir __SESSIONDIR, $plg->dir_session or die "Could not list session directory
 
 closedir __SESSIONDIR;
 #print 'debug : '. Dumper( $app )                   ;exit;
-print 'debug : '. Dumper( $plg->config->{Routes} ) ;exit;
+#print 'debug : '. Dumper( $plg->config->{Routes} ) ;exit;
 #print 'debug : '. Dumper( $plg->auth_config )      ;exit;
 #print 'debug : '. Dumper  \%TokenDB; exit;
 
@@ -772,7 +772,7 @@ Dancer2::Plugin::WebService - RESTful Web Services with login, persistent data,
 
 =head1 VERSION
 
-version 4.3.2
+version 4.3.3
 
 =head1 SYNOPSIS
 
